﻿// ***********************************************************************
// Solution         : KC.Foundation
// Project          : KC.Foundation
// File             : KolibreConfigurationException.cs
// ***********************************************************************
// <copyright>
//     Copyright © 2016 - 2018 Kolibre Credit Team. All rights reserved.
// </copyright>
// ***********************************************************************

using System;
using System.Runtime.Serialization;

namespace KC.Foundation.Model
{
    /// <summary>
    ///     Represents errors that occur during application execution.
    /// </summary>
    [Serializable]
    public class KolibreConfigurationException : KolibreException
    {
        /// <summary>
        ///     <para>Initializes a new instance of the <see cref="T:KC.Foundation.KolibreConfigurationException" /> class.</para>
        /// </summary>
        public KolibreConfigurationException()
        {
        }

        /// <summary>
        ///     <para>Initializes a new instance of <see cref="T:KC.Foundation.KolibreConfigurationException" /> class with specified error code.</para>
        /// </summary>
        /// <param name="errorCode">
        ///     <para>The error code that the exception is wrapping around.</para>
        /// </param>
        public KolibreConfigurationException(int errorCode)
            : base(errorCode)
        {
        }

        /// <summary>
        ///     <para>Initializes a new instance of the <see cref="T:KC.Foundation.KolibreConfigurationException" /> class with appropriate message.</para>
        /// </summary>
        /// <param name="message">
        ///     <para>The error message that explains the reason for this exception.</para>
        /// </param>
        public KolibreConfigurationException(string message)
            : base(message)
        {
        }

        /// <summary>
        ///     <para>Initializes a new instance of <see cref="T:KC.Foundation.KolibreConfigurationException" /> class with message and error code.</para>
        /// </summary>
        /// <param name="errorCode">
        ///     <para>The error code that the exception is wrapping around.</para>
        /// </param>
        /// <param name="message">
        ///     <para>The error message that explains the reason for the exception.</para>
        /// </param>
        public KolibreConfigurationException(int errorCode, string message)
            : base(errorCode, message)
        {
        }

        /// <summary>
        ///     <para>Initializes a new instance of the <see cref="T:KC.Foundation.KolibreException" /> class with a message and an inner exception containing detailed information.</para>
        /// </summary>
        /// <param name="errorCode">
        ///     <para>The error code that the exception is wrapping around.</para>
        /// </param>
        /// <param name="inner">
        ///     <para>The Inner Exception that provides detailed information.</para>
        /// </param>
        public KolibreConfigurationException(int errorCode, Exception inner)
            : base(errorCode, inner)
        {
        }

        /// <summary>
        ///     <para>Initializes a new instance of the <see cref="T:KC.Foundation.KolibreConfigurationException" /> class with a message and an inner exception containing detailed information.</para>
        /// </summary>
        /// <param name="message">
        ///     <para>The error message that explains the reason for this exception.</para>
        /// </param>
        /// <param name="inner">
        ///     <para>The Inner Exception that provides detailed information.</para>
        /// </param>
        public KolibreConfigurationException(string message, Exception inner)
            : base(message, inner)
        {
        }

        /// <summary>
        ///     <para>Initializes a new instance of <see cref="T:KC.Foundation.KolibreConfigurationException" /> class with specified message, inner exception and error code.</para>
        /// </summary>
        /// <param name="errorCode">
        ///     <para>The error code that the exception is wrapping around.</para>
        /// </param>
        /// <param name="message">
        ///     <para>The error message that explains the reason for the exception.</para>
        /// </param>
        /// <param name="inner">
        ///     <para>The inner exception.</para>
        /// </param>
        public KolibreConfigurationException(int errorCode, string message, Exception inner)
            : base(errorCode, message, inner)
        {
        }

        /// <summary>
        ///     <para>Initializes a new instance of the <see cref="T:KC.Foundation.KolibreConfigurationException" /> class from serialized state.</para>
        /// </summary>
        /// <param name="info">
        ///     <para>Contains serialized object data about the exception being thrown.</para>
        /// </param>
        /// <param name="context">
        ///     <para>Contains contextual information about the source or destination.</para>
        /// </param>
        protected KolibreConfigurationException(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
        }

        /// <summary>
        ///     <para>Initializes a new instance of <see cref="T:KC.Foundation.KolibreConfigurationException" /> class with specified info, context and error code.</para>
        /// </summary>
        /// <param name="info">
        ///     <para>The  <see cref="T:System.Runtime.Serialization.SerializationInfo" /> object that contains serialized object data about the exception being thrown.</para>
        /// </param>
        /// <param name="context">
        ///     <para>The  <see cref="T:System.Runtime.Serialization.StreamingContext" /> object that contains contextual information about the source or destination. The context parameter is reserved for future use, and can be specified as null.</para>
        /// </param>
        /// <param name="errorCode">
        ///     <para>The error code that the exception is wrapping around.</para>
        /// </param>
        protected KolibreConfigurationException(SerializationInfo info, StreamingContext context, int errorCode)
            : base(info, context, errorCode)
        {
        }
    }
}