﻿// ***********************************************************************
// Solution         : KC.Foundation
// Project          : KC.Foundation
// File             : IPaginatedList.cs
// Modified         : 2017-04-17  3:14 PM
// ***********************************************************************
// <copyright>
//     Copyright © 2016 - 2018 Kolibre Credit Team. All rights reserved.
// </copyright>
// ***********************************************************************

using System;
using System.Collections.Generic;

namespace KC.Foundation.Sys.Collections.Generic
{
    /// <summary>
    ///     分页列表。
    /// </summary>
    /// <typeparam name="T">列表中元素的类型。</typeparam>
    public interface IPaginatedList<T>
    {
        /// <summary>
        ///     指示是否在原数据中，该页数据是否还有下一页。
        /// </summary>
        bool HasNextPage { get; }

        /// <summary>
        ///     该页数据的页码索引，第一页的页码索引为0。
        /// </summary>
        int PageIndex { get; }

        /// <summary>
        ///     获取分页时指定的单页元素数量。
        /// </summary>
        int PageSize { get; }

        /// <summary>
        ///     获取分页时原数据的元素总数量。
        /// </summary>
        int TotalCount { get; }

        /// <summary>
        ///     获取分页时原数据的元素总页数。
        /// </summary>
        int TotalPageCount { get; }

        /// <summary>
        ///     元素列表。
        /// </summary>
        IList<T> Data { get; }

        /// <summary>
        ///     将当前的 <see cref="PaginatedList{T}" /> 实例转换为另一个 <see cref="PaginatedList{T}" /> 实例。
        /// </summary>
        /// <typeparam name="TEntity">新的<see cref="PaginatedList{T}" /> 实例的元素类型。</typeparam>
        /// <param name="selector">应用于每个元素的转换函数。</param>
        /// <returns>转换后的 <see cref="PaginatedList{T}" /> 实例。</returns>
        IPaginatedList<TEntity> ToPaginated<TEntity>(Func<T, TEntity> selector);
    }
}