﻿// ***********************************************************************
// Solution         : KC.Foundation
// Project          : KC.Foundation
// File             : NullableExtensions.cs
// Updated          : 2017-11-24 11:04 AM
// ***********************************************************************
// <copyright>
//     Copyright © 2016 - 2018 Kolibre Credit Team. All rights reserved.
// </copyright>
// ***********************************************************************

using System;

namespace KC.Foundation.Sys
{
    public static class NullableExtensions
    {
        /// <summary>
        ///     判断指定的 <see cref="Nullable" /> 是否是 <c>true</c>。
        /// </summary>
        /// <param name="b">要测试的 nullable 对象。</param>
        /// <returns>如果 <paramref name="b" /> <c>true</c>，则为 <c>true</c>；否则为 <c>false</c>。</returns>
        public static bool IsTrue(this bool? b)
        {
            return b.GetValueOrDefault(false);
        }

        /// <summary>
        ///     判断指定的 <see cref="Nullable" /> 是否是 <c>false</c>。
        /// </summary>
        /// <param name="b">要测试的 nullable 对象。</param>
        /// <returns>如果 <paramref name="b" /> 是 <c>false</c>，则为 <c>true</c>；否则为 <c>false</c>。</returns>
        public static bool IsFalse(this bool? b)
        {
            return !b.GetValueOrDefault(true);
        }

        /// <summary>
        ///     判断指定的 <see cref="Nullable" /> 是否是 <c>true</c> 或者 <c>null</c>。
        /// </summary>
        /// <param name="b">要测试的 nullable 对象。</param>
        /// <returns>如果 <paramref name="b" /> 是 <c>true</c> 或者 <c>null</c>，则为 <c>true</c>；否则为 <c>false</c>。</returns>
        public static bool IsTrueOrNull(this bool? b)
        {
            return b.GetValueOrDefault(true);
        }

        /// <summary>
        ///     判断指定的 <see cref="Nullable" /> 是否是 <c>false</c> 或者 <c>null</c>。
        /// </summary>
        /// <param name="b">要测试的 nullable 对象。</param>
        /// <returns>如果 <paramref name="b" /> 是 <c>false</c> 或者 <c>null</c>，则为 <c>true</c>；否则为 <c>false</c>。</returns>
        public static bool IsFalseOrNull(this bool? b)
        {
            return !b.GetValueOrDefault(false);
        }
    }
}