﻿// ***********************************************************************
// Solution         : KC.Foundation
// Project          : KC.Foundation
// File             : TaskExtensions.cs
// Modified         : 2017-04-17  3:14 PM
// ***********************************************************************
// <copyright>
//     Copyright © 2016 - 2018 Kolibre Credit Team. All rights reserved.
// </copyright>
// ***********************************************************************

using System;
using System.Threading.Tasks;

namespace KC.Foundation.Sys
{
    /// <summary>
    ///     <see cref="System.Threading.Tasks.Task" /> 的扩展类。
    /// </summary>
    public static class TaskExtensions
    {
        /// <summary>
        ///     配置指定的 <see cref="System.Threading.Tasks.Task" /> 实例不要在原始上下文中继续延续任务。
        /// </summary>
        /// <param name="task">指定的 <see cref="System.Threading.Tasks.Task" /> 的实例。</param>
        /// <param name="exceptionHandler">用于处理 <see cref="System.Threading.Tasks.Task" /> 执行中遇到的异常的处理方法。</param>
        public static async void Forget(this Task task, Action<Exception> exceptionHandler = null)
        {
            try
            {
                await task.ConfigureAwait(false);
            }
            catch (Exception e)
            {
                exceptionHandler?.Invoke(e);
            }
        }

        /// <summary>
        ///     更好的使用 Task.Result 的方法。
        /// </summary>
        /// <typeparam name="T">Task结果的类型。</typeparam>
        /// <param name="task"><see cref="System.Threading.Tasks.Task{T}" /> 的实例。</param>
        /// <remarks>
        ///     The rationale for GetAwaiter().GetResult() instead of .Result
        ///     is presented at https://github.com/aspnet/Security/issues/59.
        /// </remarks>
        /// <returns>Task的结果。</returns>
        public static T GetResult<T>(this Task<T> task)
        {
            return task.GetAwaiter().GetResult();
        }
    }
}