﻿// ***********************************************************************
// Solution         : KC.Foundation
// Project          : KC.Foundation
// File             : SafeRandom.cs
// Modified         : 2017-04-17  3:14 PM
// ***********************************************************************
// <copyright>
//     Copyright © 2016 - 2018 Kolibre Credit Team. All rights reserved.
// </copyright>
// ***********************************************************************

using System;
using System.Diagnostics.CodeAnalysis;
using System.Runtime.CompilerServices;
using System.Security.Cryptography;

namespace KC.Foundation.Utilities
{
    /// <summary>
    ///     Thread-safe random number generator.
    ///     Has same API as System.Random but is thread safe, similar to the implementation by Steven Toub: http://blogs.msdn.com/b/pfxteam/archive/2014/10/20/9434171.aspx
    /// </summary>
    public class SafeRandom
    {
        private static readonly RandomNumberGenerator s_globalCryptoProvider = RandomNumberGenerator.Create();

        [ThreadStatic]
        private static Random s_random;

        public int Next()
        {
            return GetRandom().Next();
        }

        public int Next(int maxValue)
        {
            return GetRandom().Next(maxValue);
        }

        public int Next(int minValue, int maxValue)
        {
            return GetRandom().Next(minValue, maxValue);
        }

        public void NextBytes(byte[] buffer)
        {
            GetRandom().NextBytes(buffer);
        }

        [SuppressMessage("ReSharper", "MemberCanBeMadeStatic.Global")]
        public double NextDouble()
        {
            return GetRandom().NextDouble();
        }

        [MethodImpl(MethodImplOptions.AggressiveInlining)]
        private static Random GetRandom()
        {
            if (s_random == null)
            {
                byte[] buffer = new byte[4];
                s_globalCryptoProvider.GetBytes(buffer);
                s_random = new Random(BitConverter.ToInt32(buffer, 0));
            }

            return s_random;
        }
    }
}